@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2020  The Software Heritage developers
+ * Copyright (C) 2020-2021  The Software Heritage developers
  * See the AUTHORS file at the top-level directory of this distribution
  * License: GNU Affero General Public License version 3, or any later version
  * See top-level LICENSE file for more information
@@ -55,11 +55,8 @@ describe('Test admin deposit page', function() {
 
     let testDeposits = responseDeposits;
 
-    cy.server();
-    cy.route({
-      method: 'GET',
-      url: `${this.Urls.admin_deposit_list()}**`,
-      response: {
+    cy.intercept(`${this.Urls.admin_deposit_list()}**`, {
+      body: {
         'draw': 10,
         'recordsTotal': testDeposits.length,
         'recordsFiltered': testDeposits.length,
