@@ -5,15 +5,18 @@
 
 from distutils.util import strtobool
 import json
-from typing import Dict
+from typing import Dict, Iterator, Union
 
 import requests
 
+from django.http.response import StreamingHttpResponse
 from rest_framework.decorators import renderer_classes
 from rest_framework.request import Request
 from rest_framework.response import Response
 
-from swh.model.identifiers import ORIGIN, parse_swhid
+from swh.model.hashutil import hash_to_hex
+from swh.model.identifiers import ExtendedObjectType, ExtendedSWHID
+from swh.model.model import Sha1Git
 from swh.web.api.apidoc import api_doc
 from swh.web.api.apiurls import api_route
 from swh.web.api.renderers import PlainTextRenderer
@@ -23,17 +26,17 @@ from swh.web.config import SWH_WEB_INTERNAL_SERVER_NAME, get_config
 API_GRAPH_PERM = "swh.web.api.graph"
 
 
-def _resolve_origin_swhid(swhid: str, origin_urls: Dict[str, str]) -> str:
+def _resolve_origin_swhid(swhid: str, origin_urls: Dict[Sha1Git, str]) -> str:
     """
     Resolve origin url from its swhid sha1 representation.
     """
-    parsed_swhid = parse_swhid(swhid)
-    if parsed_swhid.object_type == ORIGIN:
+    parsed_swhid = ExtendedSWHID.from_string(swhid)
+    if parsed_swhid.object_type == ExtendedObjectType.ORIGIN:
         if parsed_swhid.object_id in origin_urls:
             return origin_urls[parsed_swhid.object_id]
         else:
             origin_info = list(
-                archive.lookup_origins_by_sha1s([parsed_swhid.object_id])
+                archive.lookup_origins_by_sha1s([hash_to_hex(parsed_swhid.object_id)])
             )[0]
             assert origin_info is not None
             origin_urls[parsed_swhid.object_id] = origin_info["url"]
@@ -42,32 +45,32 @@ def _resolve_origin_swhid(swhid: str, origin_urls: Dict[str, str]) -> str:
         return swhid
 
 
-def _resolve_origin_swhids_in_graph_response(response: requests.Response) -> str:
+def _resolve_origin_swhids_in_graph_response(
+    response: requests.Response,
+) -> Iterator[bytes]:
     """
     Resolve origin urls from their swhid sha1 representations in graph service
     responses.
     """
     content_type = response.headers["Content-Type"]
-    origin_urls: Dict[str, str] = {}
+    origin_urls: Dict[Sha1Git, str] = {}
     if content_type == "application/x-ndjson":
-        processed_response = []
-        for line in response.text.split("\n")[:-1]:
-            swhids = json.loads(line)
+        for line in response.iter_lines():
+            swhids = json.loads(line.decode("utf-8"))
             processed_line = []
             for swhid in swhids:
                 processed_line.append(_resolve_origin_swhid(swhid, origin_urls))
-            processed_response.append(json.dumps(processed_line))
-        return "\n".join(processed_response) + "\n"
+            yield (json.dumps(processed_line) + "\n").encode()
     elif content_type == "text/plain":
-        processed_response = []
-        for line in response.text.split("\n")[:-1]:
+        for line in response.iter_lines():
             processed_line = []
-            swhids = line.split(" ")
+            swhids = line.decode("utf-8").split(" ")
             for swhid in swhids:
                 processed_line.append(_resolve_origin_swhid(swhid, origin_urls))
-            processed_response.append(" ".join(processed_line))
-        return "\n".join(processed_response) + "\n"
-    return response.text
+            yield (" ".join(processed_line) + "\n").encode()
+    else:
+        for line in response.iter_lines():
+            yield line + b"\n"
 
 
 @api_route(r"/graph/", "api-1-graph-doc")
@@ -121,7 +124,9 @@ def api_graph(request: Request) -> None:
 
 @api_route(r"/graph/(?P<graph_query>.+)/", "api-1-graph")
 @renderer_classes([PlainTextRenderer])
-def api_graph_proxy(request: Request, graph_query: str) -> Response:
+def api_graph_proxy(
+    request: Request, graph_query: str
+) -> Union[Response, StreamingHttpResponse]:
     if request.get_host() != SWH_WEB_INTERNAL_SERVER_NAME:
         if not bool(request.user and request.user.is_authenticated):
             return Response("Authentication credentials were not provided.", status=401)
@@ -133,13 +138,23 @@ def api_graph_proxy(request: Request, graph_query: str) -> Response:
     graph_query_url += graph_query
     if request.GET:
         graph_query_url += "?" + request.GET.urlencode(safe="/;:")
-    response = requests.get(graph_query_url)
-    response_text = response.text
-    resolve_origins = strtobool(request.GET.get("resolve_origins", "false"))
-    if response.status_code == 200 and resolve_origins:
-        response_text = _resolve_origin_swhids_in_graph_response(response)
-    return Response(
-        response_text,
-        status=response.status_code,
-        content_type=response.headers["Content-Type"],
-    )
+    response = requests.get(graph_query_url, stream=True)
+    # graph stats and counter endpoint responses are not streamed
+    if response.headers.get("Transfer-Encoding") != "chunked":
+        return Response(
+            response.text,
+            status=response.status_code,
+            content_type=response.headers["Content-Type"],
+        )
+    # other endpoint responses are streamed
+    else:
+        resolve_origins = strtobool(request.GET.get("resolve_origins", "false"))
+        if response.status_code == 200 and resolve_origins:
+            response_stream = _resolve_origin_swhids_in_graph_response(response)
+        else:
+            response_stream = map(lambda line: line + b"\n", response.iter_lines())
+        return StreamingHttpResponse(
+            response_stream,
+            status=response.status_code,
+            content_type=response.headers["Content-Type"],
+        )
