@@ -15,7 +15,7 @@ let visitsByDate = {};
 
 function closePopover() {
   if (currentPopover) {
-    $(currentPopover).popover('hide');
+    $(currentPopover).popover('dispose');
     currentPopover = null;
   }
 }
@@ -108,10 +108,10 @@ export function updateCalendar(year, filteredVisits, yearClickedCallback) {
 
         let visits = visitsByDate[dateStr];
         let content = '<div><h6>' + e.date.toDateString() + '</h6></div>';
-        content += '<ul style="list-style-type: none;">';
+        content += '<ul class="swh-list-unstyled">';
         for (let i = 0; i < visits.length; ++i) {
           let visitTime = visits[i].formatted_date.substr(visits[i].formatted_date.indexOf(',') + 2);
-          content += '<li><a class="swh-visit-' + visits[i].status + '" title="' + visits[i].status +
+          content += '<li><a class="swh-visit-icon swh-visit-' + visits[i].status + '" title="' + visits[i].status +
                      ' visit" href="' + visits[i].url + '">' + visitTime + '</a></li>';
         }
         content += '</ul>';
@@ -121,6 +121,19 @@ export function updateCalendar(year, filteredVisits, yearClickedCallback) {
           container: 'body',
           html: true,
           content: content
+        }).on('mouseleave', () => {
+          if (!$('.popover:hover').length) {
+            // close popover when leaving day in calendar
+            // except if the pointer is hovering it
+            closePopover();
+          }
+        });
+
+        $(e.element).on('shown.bs.popover', () => {
+          $('.popover').mouseleave(() => {
+            // close popover when pointer leaves it
+            closePopover();
+          });
         });
 
         $(e.element).popover('show');
@@ -128,12 +141,6 @@ export function updateCalendar(year, filteredVisits, yearClickedCallback) {
       }
     }
   });
-  $('#swh-visits-timeline').mouseenter(() => {
-    closePopover();
-  });
-  $('#swh-visits-list').mouseenter(() => {
-    closePopover();
-  });
   $('#swh-visits-calendar.calendar table td').css('width', maxSize + 'px');
   $('#swh-visits-calendar.calendar table td').css('height', maxSize + 'px');
   $('#swh-visits-calendar.calendar table td').css('padding', '0px');
