@@ -41,8 +41,7 @@ import 'iframe-resizer';
 // web fonts
 import 'typeface-alegreya';
 import 'typeface-alegreya-sans';
-import 'font-awesome/css/font-awesome.css';
-import './octicons.css';
+import '@mdi/font/css/materialdesignicons.css';
 
 // Monitoring
 import '@sentry/browser';
