@@ -3,22 +3,21 @@
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
-from django.shortcuts import render, redirect
-
+from django.shortcuts import redirect, render
 
 from swh.web.browse.browseurls import browse_route
 from swh.web.browse.snapshot_context import (
-    browse_snapshot_directory,
-    browse_snapshot_content,
-    browse_snapshot_log,
     browse_snapshot_branches,
+    browse_snapshot_content,
+    browse_snapshot_directory,
+    browse_snapshot_log,
     browse_snapshot_releases,
     get_snapshot_context,
 )
-from swh.web.common import service
-from swh.web.common.exc import handle_view_exception, BadInputExc
+from swh.web.common import archive
+from swh.web.common.exc import BadInputExc
 from swh.web.common.origin_visits import get_origin_visits
-from swh.web.common.utils import reverse, format_utc_iso_date, parse_timestamp
+from swh.web.common.utils import format_utc_iso_date, parse_iso8601_date_to_utc, reverse
 
 
 @browse_route(
@@ -228,16 +227,12 @@ def origin_releases_browse_legacy(request, origin_url, timestamp=None):
 
 
 def _origin_visits_browse(request, origin_url):
-    try:
+    if origin_url is None:
+        raise BadInputExc("An origin URL must be provided as query parameter.")
 
-        if origin_url is None:
-            raise BadInputExc("An origin URL must be provided as query parameter.")
-
-        origin_info = service.lookup_origin({"url": origin_url})
-        origin_visits = get_origin_visits(origin_info)
-        snapshot_context = get_snapshot_context(origin_url=origin_url)
-    except Exception as exc:
-        return handle_view_exception(request, exc)
+    origin_info = archive.lookup_origin({"url": origin_url})
+    origin_visits = get_origin_visits(origin_info)
+    snapshot_context = get_snapshot_context(origin_url=origin_url)
 
     for i, visit in enumerate(origin_visits):
         url_date = format_utc_iso_date(visit["date"], "%Y-%m-%dT%H:%M:%SZ")
@@ -255,7 +250,7 @@ def _origin_visits_browse(request, origin_url):
         visit["url"] = reverse("browse-origin-directory", query_params=query_params,)
         if not snapshot:
             visit["snapshot"] = ""
-        visit["date"] = parse_timestamp(visit["date"]).timestamp()
+        visit["date"] = parse_iso8601_date_to_utc(visit["date"]).timestamp()
 
     heading = "Origin visits - %s" % origin_url
 
