@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2020  The Software Heritage developers
+# Copyright (C) 2015-2021  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -298,6 +298,7 @@ def search_origin(
     url_pattern: str,
     limit: int = 50,
     with_visit: bool = False,
+    visit_types: Optional[List[str]] = None,
     page_token: Optional[str] = None,
 ) -> Tuple[List[OriginInfo], Optional[str]]:
     """Search for origins whose urls contain a provided string pattern
@@ -306,6 +307,9 @@ def search_origin(
     Args:
         url_pattern: the string pattern to search for in origin urls
         limit: the maximum number of found origins to return
+        with_visit: Whether origins with no visit are to be filtered out
+        visit_types: Only origins having any of the provided visit types
+            (e.g. git, svn, pypi) will be returned
         page_token: opaque string used to get the next results of a search
 
     Returns:
@@ -320,6 +324,7 @@ def search_origin(
             url_pattern=url_pattern,
             page_token=page_token,
             with_visit=with_visit,
+            visit_types=visit_types,
             limit=limit,
         )
         origins = [converters.from_origin(ori_dict) for ori_dict in page_result.results]
@@ -339,6 +344,7 @@ def search_origin(
             page_token=page_token,
             with_visit=with_visit,
             limit=limit,
+            visit_types=visit_types,
             regexp=True,
         )
         origins = [converters.from_origin(ori.to_dict()) for ori in page_result.results]
@@ -359,11 +365,18 @@ def search_origin_metadata(
         Iterable of origin metadata information for existing origins
 
     """
-    matches = idx_storage.origin_intrinsic_metadata_search_fulltext(
-        conjunction=[fulltext], limit=limit
-    )
-    matches = [match.to_dict() for match in matches]
     results = []
+    if search and config.get_config()["metadata_search_backend"] == "swh-search":
+        page_result = search.origin_search(metadata_pattern=fulltext, limit=limit,)
+        matches = idx_storage.origin_intrinsic_metadata_get(
+            [r["url"] for r in page_result.results]
+        )
+    else:
+        matches = idx_storage.origin_intrinsic_metadata_search_fulltext(
+            conjunction=[fulltext], limit=limit
+        )
+
+    matches = [match.to_dict() for match in matches]
     origins = storage.origin_get([match["id"] for match in matches])
     for origin, match in zip(origins, matches):
         if not origin:
@@ -371,6 +384,7 @@ def search_origin_metadata(
         match["from_revision"] = hashutil.hash_to_hex(match["from_revision"])
         del match["id"]
         results.append(OriginMetadataInfo(url=origin.url, metadata=match))
+
     return results
 
 
@@ -581,7 +595,10 @@ def lookup_revision_message(rev_sha1_git) -> Dict[str, bytes]:
 def _lookup_revision_id_by(origin, branch_name, timestamp):
     def _get_snapshot_branch(snapshot, branch_name):
         snapshot = lookup_snapshot(
-            visit["snapshot"], branches_from=branch_name, branches_count=10
+            visit["snapshot"],
+            branches_from=branch_name,
+            branches_count=10,
+            branch_name_exclude_prefix=None,
         )
         branch = None
         if branch_name in snapshot["branches"]:
@@ -977,7 +994,7 @@ def lookup_origin_visit_latest(
 
     """
 
-    visit_and_status = origin_get_latest_visit_status(
+    visit_status = origin_get_latest_visit_status(
         storage,
         origin_url,
         type=type,
@@ -985,11 +1002,7 @@ def lookup_origin_visit_latest(
         require_snapshot=require_snapshot,
     )
     return (
-        converters.from_origin_visit(
-            {**visit_and_status[0].to_dict(), **visit_and_status[1].to_dict()}
-        )
-        if visit_and_status
-        else None
+        converters.from_origin_visit(visit_status.to_dict()) if visit_status else None
     )
 
 
@@ -1013,7 +1026,9 @@ def lookup_origin_visit(origin_url: str, visit_id: int) -> OriginVisitInfo:
     return converters.from_origin_visit({**visit_status.to_dict(), "type": visit.type})
 
 
-def lookup_snapshot_sizes(snapshot_id: str) -> Dict[str, int]:
+def lookup_snapshot_sizes(
+    snapshot_id: str, branch_name_exclude_prefix: Optional[str] = "refs/pull/"
+) -> Dict[str, int]:
     """Count the number of branches in the snapshot with the given id
 
     Args:
@@ -1025,7 +1040,10 @@ def lookup_snapshot_sizes(snapshot_id: str) -> Dict[str, int]:
     """
     snapshot_id_bin = _to_sha1_bin(snapshot_id)
     snapshot_sizes = dict.fromkeys(("alias", "release", "revision"), 0)
-    branch_counts = storage.snapshot_count_branches(snapshot_id_bin)
+    branch_counts = storage.snapshot_count_branches(
+        snapshot_id_bin,
+        branch_name_exclude_prefix.encode() if branch_name_exclude_prefix else None,
+    )
     # remove possible None key returned by snapshot_count_branches
     # when null branches are present in the snapshot
     branch_counts.pop(None, None)
@@ -1034,31 +1052,49 @@ def lookup_snapshot_sizes(snapshot_id: str) -> Dict[str, int]:
 
 
 def lookup_snapshot(
-    snapshot_id, branches_from="", branches_count=1000, target_types=None
-):
+    snapshot_id: str,
+    branches_from: str = "",
+    branches_count: int = 1000,
+    target_types: Optional[List[str]] = None,
+    branch_name_include_substring: Optional[str] = None,
+    branch_name_exclude_prefix: Optional[str] = "refs/pull/",
+) -> Dict[str, Any]:
     """Return information about a snapshot, aka the list of named
     branches found during a specific visit of an origin.
 
     Args:
-        snapshot_id (str): sha1 identifier of the snapshot
-        branches_from (str): optional parameter used to skip branches
+        snapshot_id: sha1 identifier of the snapshot
+        branches_from: optional parameter used to skip branches
             whose name is lesser than it before returning them
-        branches_count (int): optional parameter used to restrain
+        branches_count: optional parameter used to restrain
             the amount of returned branches
-        target_types (list): optional parameter used to filter the
+        target_types: optional parameter used to filter the
             target types of branch to return (possible values that can be
             contained in that list are `'content', 'directory',
             'revision', 'release', 'snapshot', 'alias'`)
+        branch_name_include_substring: if provided, only return branches whose name
+            contains given substring
+        branch_name_exclude_prefix: if provided, do not return branches whose name
+            starts with given pattern
+
 
     Returns:
         A dict filled with the snapshot content.
     """
     snapshot_id_bin = _to_sha1_bin(snapshot_id)
     partial_branches = storage.snapshot_get_branches(
-        snapshot_id_bin, branches_from.encode(), branches_count, target_types
+        snapshot_id_bin,
+        branches_from.encode(),
+        branches_count,
+        target_types,
+        branch_name_include_substring.encode()
+        if branch_name_include_substring
+        else None,
+        branch_name_exclude_prefix.encode() if branch_name_exclude_prefix else None,
     )
     if not partial_branches:
         raise NotFoundExc(f"Snapshot with id {snapshot_id} not found!")
+
     return converters.from_partial_branches(partial_branches)
 
 
@@ -1086,41 +1122,6 @@ def lookup_latest_origin_snapshot(
     return converters.from_snapshot(snp.to_dict()) if snp is not None else None
 
 
-def lookup_snapshot_branch_name_from_tip_revision(
-    snapshot_id: str, revision_id: str
-) -> Optional[str]:
-    """Check if a revision corresponds to the tip of a snapshot branch
-
-    Args:
-        snapshot_id: hexadecimal representation of a snapshot id
-        revision_id: hexadecimal representation of a revision id
-
-    Returns:
-        The name of the first found branch or None otherwise
-    """
-    per_page = 10000
-    branches_from = ""
-    snapshot: Dict[str, Any] = {"branches": {}}
-    branches = []
-    while not branches_from or len(snapshot["branches"]) == per_page + 1:
-        snapshot = lookup_snapshot(
-            snapshot_id,
-            target_types=[REVISION],
-            branches_from=branches_from,
-            branches_count=per_page + 1,
-        )
-
-        branches += [
-            {"name": k, "target": v["target"]} for k, v in snapshot["branches"].items()
-        ]
-        branches_from = branches[-1]["name"]
-
-    for branch in branches:
-        if branch["target"] == revision_id:
-            return branch["name"]
-    return None
-
-
 def lookup_snapshot_alias(
     snapshot_id: str, alias_name: str
 ) -> Optional[Dict[str, Any]]:
