@@ -14,8 +14,9 @@ class SaveAuthorizedOrigin(models.Model):
     url = models.CharField(max_length=200, null=False)
 
     class Meta:
-        app_label = "swh.web.common"
+        app_label = "swh_web_common"
         db_table = "save_authorized_origin"
+        indexes = [models.Index(fields=["url"])]
 
     def __str__(self):
         return self.url
@@ -30,8 +31,9 @@ class SaveUnauthorizedOrigin(models.Model):
     url = models.CharField(max_length=200, null=False)
 
     class Meta:
-        app_label = "swh.web.common"
+        app_label = "swh_web_common"
         db_table = "save_unauthorized_origin"
+        indexes = [models.Index(fields=["url"])]
 
     def __str__(self):
         return self.url
@@ -81,9 +83,10 @@ class SaveOriginRequest(models.Model):
     )
 
     class Meta:
-        app_label = "swh.web.common"
+        app_label = "swh_web_common"
         db_table = "save_origin_request"
         ordering = ["-id"]
+        indexes = [models.Index(fields=["origin_url", "status"])]
 
     def __str__(self):
         return str(
