@@ -16,6 +16,26 @@ from swh.web import settings
 
 SWH_WEB_INTERNAL_SERVER_NAME = "archive.internal.softwareheritage.org"
 
+STAGING_SERVER_NAMES = [
+    "webapp.staging.swh.network",
+    "webapp.internal.staging.swh.network",
+]
+
+ORIGIN_VISIT_TYPES = [
+    "cran",
+    "deb",
+    "deposit",
+    "ftp",
+    "hg",
+    "git",
+    "nixguix",
+    "npm",
+    "pypi",
+    "svn",
+    "tar",
+]
+
+
 SETTINGS_DIR = os.path.dirname(settings.__file__)
 
 DEFAULT_CONFIG = {
@@ -74,7 +94,7 @@ DEFAULT_CONFIG = {
     "scheduler": ("dict", {"cls": "remote", "url": "http://127.0.0.1:5008/"}),
     "development_db": ("string", os.path.join(SETTINGS_DIR, "db.sqlite3")),
     "test_db": ("string", os.path.join(SETTINGS_DIR, "testdb.sqlite3")),
-    "production_db": ("string", "/var/lib/swh/web.sqlite3"),
+    "production_db": ("dict", {"name": "swh-web"}),
     "deposit": (
         "dict",
         {
@@ -103,6 +123,8 @@ DEFAULT_CONFIG = {
             "json_path": "1.0/status/578e5eddcdc0cc7951000520",
         },
     ),
+    "metadata_search_backend": ("string", "swh-indexer-storage"),  # or "swh-search"
+    "staging_server_names": ("list", STAGING_SERVER_NAMES),
 }
 
 swhweb_config = {}  # type: Dict[str, Any]
