@@ -4,6 +4,7 @@
 # See top-level LICENSE file for more information
 
 from datetime import timedelta
+import json
 
 from hypothesis import given
 import pytest
@@ -518,6 +519,34 @@ def test_api_origin_search_words(api_client, mocker, backend):
     }
 
 
+@pytest.mark.parametrize("backend", ["swh-search", "swh-storage"])
+def test_api_origin_search_visit_type(api_client, mocker, backend):
+    if backend != "swh-search":
+        # equivalent to not configuring search in the config
+        mocker.patch("swh.web.common.archive.search", None)
+
+    expected_origins = {
+        "https://github.com/wcoder/highlightjs-line-numbers.js",
+        "https://github.com/memononen/libtess2",
+    }
+
+    url = reverse(
+        "api-1-origin-search",
+        url_args={"url_pattern": "github com",},
+        query_params={"visit_type": "git"},
+    )
+    rv = check_api_get_responses(api_client, url, status_code=200)
+    assert {origin["url"] for origin in rv.data} == expected_origins
+
+    url = reverse(
+        "api-1-origin-search",
+        url_args={"url_pattern": "github com",},
+        query_params={"visit_type": "foo"},
+    )
+    rv = check_api_get_responses(api_client, url, status_code=200)
+    assert rv.data == []
+
+
 @pytest.mark.parametrize("backend", ["swh-search", "swh-storage"])
 @pytest.mark.parametrize("limit", [1, 2, 3, 10])
 def test_api_origin_search_scroll(api_client, archive_data, mocker, limit, backend):
@@ -565,7 +594,11 @@ def test_api_origin_search_limit(api_client, archive_data, tests_data, mocker, b
     assert len(rv.data) == 1000
 
 
-def test_api_origin_metadata_search(api_client):
+@pytest.mark.parametrize("backend", ["swh-search", "swh-indexer-storage"])
+def test_api_origin_metadata_search(api_client, mocker, backend):
+
+    mock_config = mocker.patch("swh.web.common.archive.config")
+    mock_config.get_config.return_value = {"metadata_search_backend": backend}
 
     url = reverse(
         "api-1-origin-metadata-search", query_params={"fulltext": ORIGIN_METADATA_VALUE}
@@ -583,14 +616,21 @@ def test_api_origin_metadata_search(api_client):
                     "configuration": INDEXER_TOOL["tool_configuration"],
                     "id": INDEXER_TOOL["id"],
                 },
-                "metadata": {ORIGIN_METADATA_KEY: ORIGIN_METADATA_VALUE},
                 "mappings": [],
             },
         }
         for origin_url, master_rev in ORIGIN_MASTER_REVISION.items()
     ]
 
-    assert rv.data == expected_data
+    for i in range(len(expected_data)):
+        expected = expected_data[i]
+        response = rv.data[i]
+        metadata = response["metadata"].pop("metadata")
+
+        assert any(
+            [ORIGIN_METADATA_VALUE in json.dumps(val) for val in metadata.values()]
+        )
+        assert response == expected
 
 
 def test_api_origin_metadata_search_limit(api_client, mocker):
