@@ -17,9 +17,17 @@ from swh.indexer.mimetype import MimetypeIndexer
 from swh.indexer.storage import get_indexer_storage
 from swh.indexer.storage.model import OriginIntrinsicMetadataRow
 from swh.loader.git.from_disk import GitLoaderFromArchive
-from swh.model.hashutil import DEFAULT_ALGORITHMS, hash_to_bytes, hash_to_hex
-from swh.model.model import Content, Directory, Origin, OriginVisit, OriginVisitStatus
+from swh.model.hashutil import DEFAULT_ALGORITHMS, hash_to_hex
+from swh.model.model import (
+    Content,
+    Directory,
+    Origin,
+    OriginVisit,
+    OriginVisitStatus,
+    Snapshot,
+)
 from swh.search import get_search
+from swh.storage import get_storage
 from swh.storage.algos.dir_iterators import dir_iterator
 from swh.storage.algos.snapshot import snapshot_get_latest
 from swh.storage.interface import Sha1
@@ -34,13 +42,6 @@ from swh.web.common import archive
 
 # Module used to initialize data that will be provided as tests input
 
-# Configuration for git loader
-_TEST_LOADER_CONFIG = {
-    "storage": {"cls": "memory",},
-    "save_data": False,
-    "max_content_size": 100 * 1024 * 1024,
-}
-
 # Base content indexer configuration
 _TEST_INDEXER_BASE_CONFIG = {
     "storage": {"cls": "memory"},
@@ -127,11 +128,15 @@ _TEST_ORIGINS = [
             "highlightjs-line-numbers.js.zip",
             "highlightjs-line-numbers.js_visit2.zip",
         ],
+        "metadata": {"description": "Line numbering plugin for Highlight.js",},
     },
     {
         "type": "git",
         "url": "repo_with_submodules",
         "archives": ["repo_with_submodules.tgz"],
+        "metadata": {
+            "description": "This is just a sample repository with submodules",
+        },
     },
 ]
 
@@ -168,10 +173,31 @@ ORIGIN_METADATA_VALUE = "git"
 ORIGIN_MASTER_REVISION = {}
 
 
+def _add_origin(storage, search, origin_url, visit_type="git", snapshot_branches={}):
+    storage.origin_add([Origin(url=origin_url)])
+    search.origin_update(
+        [{"url": origin_url, "has_visits": True, "visit_types": [visit_type]}]
+    )
+    date = now()
+    visit = OriginVisit(origin=origin_url, date=date, type=visit_type)
+    visit = storage.origin_visit_add([visit])[0]
+    snapshot = Snapshot.from_dict({"branches": snapshot_branches})
+    storage.snapshot_add([snapshot])
+    visit_status = OriginVisitStatus(
+        origin=origin_url,
+        visit=visit.visit,
+        date=date + timedelta(minutes=1),
+        type=visit.type,
+        status="full",
+        snapshot=snapshot.id,
+    )
+    storage.origin_visit_status_add([visit_status])
+
+
 # Tests data initialization
 def _init_tests_data():
     # To hold reference to the memory storage
-    storage = None
+    storage = get_storage("memory")
 
     # Create search instance
     search = get_search("memory")
@@ -196,36 +222,22 @@ def _init_tests_data():
                 os.path.dirname(__file__), "resources/repos/%s" % archive_
             )
             loader = GitLoaderFromArchive(
-                origin["url"],
-                archive_path=origin_repo_archive,
-                config=_TEST_LOADER_CONFIG,
+                storage, origin["url"], archive_path=origin_repo_archive,
             )
-            if storage is None:
-                storage = loader.storage
-            else:
-                loader.storage = storage
-            loader.load()
+
+            result = loader.load()
+            assert result["status"] == "eventful"
 
         ori = storage.origin_get([origin["url"]])[0]
         origin.update(ori.to_dict())  # add an 'id' key if enabled
-        search.origin_update([{"url": origin["url"], "has_visits": True}])
+        search.origin_update(
+            [{"url": origin["url"], "has_visits": True, "visit_types": ["git"]}]
+        )
 
     for i in range(250):
-        url = "https://many.origins/%d" % (i + 1)
-        # storage.origin_add([{'url': url}])
-        storage.origin_add([Origin(url=url)])
-        search.origin_update([{"url": url, "has_visits": True}])
-        date = now()
-        visit = OriginVisit(origin=url, date=date, type="tar")
-        visit = storage.origin_visit_add([visit])[0]
-        visit_status = OriginVisitStatus(
-            origin=url,
-            visit=visit.visit,
-            date=date + timedelta(minutes=1),
-            status="full",
-            snapshot=hash_to_bytes("1a8893e6a86f444e8be8e7bda6cb34fb1735a00e"),
+        _add_origin(
+            storage, search, origin_url=f"https://many.origins/{i+1}", visit_type="tar"
         )
-        storage.origin_visit_status_add([visit_status])
 
     sha1s: Set[Sha1] = set()
     directories = set()
@@ -236,6 +248,7 @@ def _init_tests_data():
     content_path = {}
 
     # Get all objects loaded into the test archive
+    common_metadata = {ORIGIN_METADATA_KEY: ORIGIN_METADATA_VALUE}
     for origin in _TEST_ORIGINS:
         snp = snapshot_get_latest(storage, origin["url"])
         snapshots.add(hash_to_hex(snp.id))
@@ -245,14 +258,20 @@ def _init_tests_data():
                 revisions.add(branch_data.target)
                 if b"master" in branch_name:
                     # Add some origin intrinsic metadata for tests
+                    metadata = common_metadata
+                    metadata.update(origin.get("metadata", {}))
                     origin_metadata = OriginIntrinsicMetadataRow(
                         id=origin["url"],
                         from_revision=branch_data.target,
                         indexer_configuration_id=idx_tool["id"],
-                        metadata={ORIGIN_METADATA_KEY: ORIGIN_METADATA_VALUE},
+                        metadata=metadata,
                         mappings=[],
                     )
                     idx_storage.origin_intrinsic_metadata_add([origin_metadata])
+                    search.origin_update(
+                        [{"url": origin["url"], "intrinsic_metadata": metadata}]
+                    )
+
                     ORIGIN_MASTER_REVISION[origin["url"]] = hash_to_hex(
                         branch_data.target
                     )
@@ -320,6 +339,26 @@ def _init_tests_data():
     # Add empty content to the test archive
     storage.content_add([Content.from_data(data=b"")])
 
+    # Add fake git origin with pull request branches
+    _add_origin(
+        storage,
+        search,
+        origin_url="https://git.example.org/project",
+        snapshot_branches={
+            b"refs/heads/master": {
+                "target_type": "revision",
+                "target": next(iter(revisions)),
+            },
+            **{
+                f"refs/pull/{i}".encode(): {
+                    "target_type": "revision",
+                    "target": next(iter(revisions)),
+                }
+                for i in range(300)
+            },
+        },
+    )
+
     # Return tests data
     return {
         "search": search,
